
#-*- coding: utf-8 -*-
"""
Todo
----
insert module comments in this space.

"""

__title__ = "gitlab-management"
__version__ = "0.2.0rc200621014534"
__doc__ = "https://gitlab.com/nofusscomputing/projects/python-gitlab-management"
__author__ = "No Fuss Computing"
__email__ = "helpdesk@nofusscomputing.com"
__license__ = "GNU LGPLv3"
__copyright__ = "(C) All Rights reserved"
__source__ = "https://gitlab.com/nofusscomputing/projects/python-gitlab-management/-/tree/050c20431027df92574f2f6e2b97e88d670b65d2"
